@@ -6,7 +6,7 @@ def movFile(images,dirname):
     if os.path.exists(dirpath):
         print("warning:{} is exists before create".format(dirpath))
     else:
-        os.mkdirs(dirpath)
+        os.mkdir(dirpath)
     
     for image in images:
         imgpath = os.path.join(curpath,image)
